@@ -26,14 +26,13 @@
 #include <KStandardGameAction>
 #include <KActionCollection>
 #include <KToggleAction>
-#include <KStatusBar>
 #include <KScoreDialog>
 #include <KConfigDialog>
 #include <KgThemeSelector>
 #include <KMessageBox>
-#include <KLocale>
+
+#include <QStatusBar>
 #include <QDesktopWidget>
-#include <QPointer>
 
 #include "ui_customgame.h"
 #include "ui_generalopts.h"
@@ -87,9 +86,10 @@ private:
 KMinesMainWindow::KMinesMainWindow()
 {
     m_scene = new KMinesScene(this);
-    connect(m_scene, SIGNAL(minesCountChanged(int)), SLOT(onMinesCountChanged(int)));
-    connect(m_scene, SIGNAL(gameOver(bool)), SLOT(onGameOver(bool)));
-    connect(m_scene, SIGNAL(firstClickDone()), SLOT(onFirstClick()));
+    
+    connect(m_scene, &KMinesScene::minesCountChanged, this, &KMinesMainWindow::onMinesCountChanged);
+    connect(m_scene, &KMinesScene::gameOver, this, &KMinesMainWindow::onGameOver);
+    connect(m_scene, &KMinesScene::firstClickDone, this, &KMinesMainWindow::onFirstClick);
 
     m_view = new KMinesView( m_scene, this );
     m_view->setCacheMode( QGraphicsView::CacheBackground );
@@ -103,10 +103,13 @@ KMinesMainWindow::KMinesMainWindow()
 
 
     m_gameClock = new KGameClock(this, KGameClock::MinSecOnly);
-    connect(m_gameClock, SIGNAL(timeChanged(QString)), SLOT(advanceTime(QString)));
+    connect(m_gameClock, &KGameClock::timeChanged, this, &KMinesMainWindow::advanceTime);
 
-    statusBar()->insertItem( i18n("Mines: 0/0"), 0 );
-    statusBar()->insertItem( i18n("Time: 00:00"), 1);
+    mineLabel->setText(i18n("Mines: 0/0"));
+    timeLabel->setText(i18n("Time: 00:00"));
+    
+    statusBar()->insertPermanentWidget( 0, mineLabel );
+    statusBar()->insertPermanentWidget( 1, timeLabel );
     setCentralWidget(m_view);
     setupActions();
 
@@ -136,11 +139,12 @@ void KMinesMainWindow::setupActions()
 
 void KMinesMainWindow::onMinesCountChanged(int count)
 {
-    statusBar()->changeItem( i18n("Mines: %1/%2", count, m_scene->totalMines()), 0 );
+    mineLabel->setText(i18n("Mines: %1/%2", count, m_scene->totalMines()));
 }
 
 void KMinesMainWindow::newGame()
 {
+    qDebug() << "Inside game";
     m_gameClock->restart();
     m_gameClock->pause(); // start only with the 1st click
 
@@ -172,7 +176,8 @@ void KMinesMainWindow::newGame()
             //unsupported
             break;
     }
-    statusBar()->changeItem( i18n("Time: 00:00"), 1);
+    
+    timeLabel->setText(i18n("Time: 00:00"));
 }
 
 void KMinesMainWindow::onGameOver(bool won)
@@ -202,7 +207,7 @@ void KMinesMainWindow::onGameOver(bool won)
 
 void KMinesMainWindow::advanceTime(const QString& timeStr)
 {
-    statusBar()->changeItem( i18n("Time: %1", timeStr), 1 );
+    timeLabel->setText(i18n("Time: %1", timeStr));
 }
 
 void KMinesMainWindow::onFirstClick()
@@ -232,8 +237,8 @@ void KMinesMainWindow::configureSettings()
     dialog->addPage( new KgThemeSelector( m_scene->renderer().themeProvider() ), i18n( "Theme" ), QLatin1String( "games-config-theme" ));
     dialog->addPage( new CustomGameConfig( dialog ), i18n("Custom Game"), QLatin1String( "games-config-custom" ));
     connect( m_scene->renderer().themeProvider(), SIGNAL(currentThemeChanged(const KgTheme*)), SLOT(loadSettings()) );
-    connect( dialog, SIGNAL(settingsChanged(QString)), this, SLOT(loadSettings()) );
-    dialog->setHelp(QString(),QLatin1String( "kmines" ));
+    connect(dialog, &KConfigDialog::settingsChanged, this, &KMinesMainWindow::loadSettings);
+    
     dialog->show();
 }
 
